rlog

package
v0.11.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 6, 2026 License: MIT Imports: 5 Imported by: 0

Documentation

Overview

Package rlog provides a simple file logger for rdr. All components write to a single <home>/rdr.log file.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Close

func Close()

Close flushes and closes the log file.

func Error

func Error(component string, err error)

Error writes an error entry.

func Init

func Init(dir string)

Init sets the log directory and opens the log file. Call once from main/ui init.

func Log

func Log(component, msg string)

Log writes a timestamped message to the log file.

func LogPath

func LogPath() string

LogPath returns the path to the log file.

func Logf

func Logf(component, format string, args ...any)

Logf writes a formatted timestamped message.

Types

This section is empty.

Jump to