package
Version:
v0.11.0
Opens a new window with list of versions in this module.
Published: May 6, 2026
License: MIT
Opens a new window with license information.
Imports: 5
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package rlog provides a simple file logger for rdr.
All components write to a single <home>/rdr.log file.
Close flushes and closes the log file.
Error writes an error entry.
Init sets the log directory and opens the log file.
Call once from main/ui init.
func Log(component, msg string)
Log writes a timestamped message to the log file.
LogPath returns the path to the log file.
func Logf(component, format string, args ...any)
Logf writes a formatted timestamped message.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.